mkdocs build
cp -r site/* ~/dev/www/dystroy/safecloset/

# deploy on dystroy.org
~/dev/www/dystroy/deploy.sh


